# TODO: glslc docs using asciidoctor
Summary:	Collection of tools, libraries and tests for shader compilation
Summary(pl.UTF-8):	Zestaw narzędzi, bibliotek i testów do kompilacji shaderów
Name:		shaderc
Version:	2024.0
Release:	1%{?tld}
License:	Apache v2.0
Group:		Libraries
#Source0Download: https://github.com/google/shaderc/tags
Source0:	https://github.com/google/shaderc/archive/v%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	c29fbe8f3c10fc0097e04327e1f64a73
Patch0:		%{name}-system-libs.patch
Patch1:		%{name}-shared.patch
URL:		https://github.com/google/shaderc
# for docs
#BuildRequires:	asciidoctor
BuildRequires:	cmake >= 3.17.2
BuildRequires:	glslang-devel >= 12
BuildRequires:	libstdc++-devel >= 6:7
BuildRequires:	python3 >= 1:3
BuildRequires:	rpmbuild(macros) >= 1.605
BuildRequires:	spirv-tools >= 1:2022.4
BuildRequires:	spirv-tools-devel >= 1:2022.4
%requires_ge	glslang
%requires_ge_to	spirv-tools-libs spirv-tools-devel
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
A collection of tools, libraries and tests for shader compilation. At
the moment it includes:
 - glslc, a command line compiler for GLSL/HLSL to SPIR-V, and
 - libshaderc, a library API for doing the same.

Shaderc wraps around core functionality in glslang and SPIRV-Tools.
Shaderc aims to to provide:
 - a command line compiler with GCC- and Clang-like usage, for better
   integration with build systems
 - an API where functionality can be added without breaking existing
   clients
 - an API supporting standard concurrency patterns across multiple
   operating systems
 - increased functionality such as file #include support

%description -l pl.UTF-8
Zestaw narzędzi, bibliotek i testów do kompilacji shaderów. Obecnie
zawiera:
 - glslc - kompilator linii poleceń dla GLSL/HLSL do SPIR-V
 - libshaderc - biblioteka do tego samego

Shaderc obudowuje podstawową funkcjonalność glslang i SPIRV-Tools.
Celem shaderc jest zapewnienie:
 - kompilatora linii poleceń używalnego podobnie do GCC czy Clang
   (w celu lepszej integracji z systemami budowania)
 - API, do którego można dodawać funkcjonalność bez psucia
   istniejących klientów
 - API obsługującego standardowe wzorce współbieżności na wielu
   systemach operacyjnych
 - zwiększonej funkcjonalności, np. obsługi #include

%package devel
Summary:	Header files for shaderc library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki shaderc
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description devel
Header files for shaderc library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki shaderc.

%package static
Summary:	Static shaderc libraries
Summary(pl.UTF-8):	Statyczne biblioteki shaderc
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static shaderc libraries.

%description static -l pl.UTF-8
Statyczne biblioteki shaderc.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

# open(..., errors='replace') requires Python 3
%{__sed} -i -e '1s,/usr/bin/env python$,%{__python3},' utils/update_build_version.py

%build
%cmake -B build \
	-DCMAKE_INSTALL_INCLUDEDIR=include \
	-DCMAKE_INSTALL_LIBDIR=%{_lib} \
	-DSHADERC_SKIP_TESTS=ON

%{__make} -C build

%install
rm -rf $RPM_BUILD_ROOT

%{__make} -C build install \
	DESTDIR=$RPM_BUILD_ROOT

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc AUTHORS CHANGES CONTRIBUTORS README.md  glslc/README.asciidoc
%attr(755,root,root) %{_bindir}/glslc
%attr(755,root,root) %{_libdir}/libshaderc.so.1

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libshaderc.so
%{_includedir}/shaderc
%{_pkgconfigdir}/shaderc.pc
%{_pkgconfigdir}/shaderc_combined.pc
%{_pkgconfigdir}/shaderc_static.pc

%files static
%defattr(644,root,root,755)
%{_libdir}/libshaderc.a
%{_libdir}/libshaderc_combined.a
%changelog
* Wed Apr 03 2024 TLD Linux <feedback@tld-linux.org>
- For complete changelog see: http://git.tld-linux.org/?p=packages/shaderc.git;a=log;h=master

* Wed Apr 03 2024 Marcin Krol <hawk@tld-linux.org> 704ab2b
- updated to 2024.0

* Sun Feb 18 2024 Jakub Bogusz <qboosh@pld-linux.org> 6755cd7
- updated to 2023.8 (ready for glslang 14)

* Fri Apr 28 2023 Jakub Bogusz <qboosh@pld-linux.org> 55eaada
- fixed includedir and libdir in .pc file; release 2

* Tue Apr 04 2023 Jakub Bogusz <qboosh@pld-linux.org> 4f7f76b
- updated to 2023.3, adjusted for glslang 12

* Mon Dec 27 2021 Jakub Bogusz <qboosh@pld-linux.org> 8ba1551
- updated to 2021.3

* Sun May 02 2021 Jan Palus <atler@pld-linux.org> cbd2c1f
- macros for %cmake

* Sun May 02 2021 Jan Palus <atler@pld-linux.org> 7794a13
- fixup pc file for updated shared library name; rel 2

* Wed Apr 28 2021 Jakub Bogusz <qboosh@pld-linux.org> 6ce1aef
- rediffed

* Wed Apr 28 2021 Jakub Bogusz <qboosh@pld-linux.org> 28ae127
- updated to 2021.0
- updated shared patch

* Tue Jul 14 2020 Jan Palus <atler@pld-linux.org> b1d33a4
- up to 2020.0 (fixes compatibility with new glslang)

* Sun Mar 15 2020 Jakub Bogusz <qboosh@pld-linux.org> b9261a9
- updated to 2019.1
- updated system-libs patch

* Sat Sep 21 2019 Jakub Bogusz <qboosh@pld-linux.org> 974b6b9
- C++ 11 and python 3 required now

* Sat Sep 21 2019 Jan Palus <atler@pld-linux.org> f90ff74
- up to 2019.0

* Fri Oct 26 2018 Jakub Bogusz <qboosh@pld-linux.org> 5153f56
- initial

